@@ -17,6 +17,7 @@
   ## some configuration
   .Tcl("option add *tearOff 0")         # disable tearoff menus
 
+  
   ## load in tcl packages
   ## from tcltk2 we have this
   tclRequire("autoscroll")
@@ -25,6 +26,12 @@
 
   ## genearte stock icons
   loadGWidgetIcons()
+
+  ## use.table options
+  ## images from http://ryanfait.com/resources/custom-checkboxes-and-radio-buttons/. Thanks
+  tkimage.create("photo", "::image::off", file=system.file("images", "checkbutton-off.gif", package="gWidgetstcltk"))
+  tkimage.create("photo", "::image::on",  file=system.file("images", "checkbutton-on.gif",  package="gWidgetstcltk"))
+
 }
          
 
